
	var svg = d3.select('svg');

	var width = +svg.attr('width');
	var height = +svg.attr('height');

	var colors = ['#fff7ec','#fee8c8','#fdd49e','#fdbb84','#fc8d59','#ef6548','#d7301f','#b30000','#7f0000']
	var margin = {top: 100, right: 100, bottom: 100, left: 100};
	var innerWidth = width - margin.left - margin.right;
	var innerHeight = height - margin.top - margin.bottom;
	var title = "Visualizing Earthquake Counts State 2010-2015 (M3+)";
	var heatData = [];


	//importing and reworking data
	d3.csv('https://vizhub.com/Mike191/datasets/earthquakes_states.csv')
	  .then(function(data) {
	  
		for(var x = 0; x < data.length; x++){
		  	for(var y = 0; y < 6; y++){
		   		heatData.push({
		      		"Year": Object.keys(data[x])[y], 
		      		"Count": Object.values(data[x])[y], 
		      		"States": data[x]["States"], 
		      		"Category": data[x]["Category"]
		    });
		  }
		}


		var xValues = d3.set(heatData.map(function(d){
			return d["States"]})).values();

		var yValues = d3.set(heatData.map(function(d){
			return d["Year"]})).values();

		var selectValues = d3.set(heatData.map(function(d){
			return d["Category"]})).values();

		var yValues = d3.set(heatData.map(function(d){
			return d["Year"]})).values();

    	console.log(heatData)
    
    
    
    //creating the dropdown box
		var dropDown = d3.select("#selectButton")
			.selectAll('MagnitudeButton')
			.data(selectValues.sort())
			.enter()
			.append('option')
			.text(function (d) { 
				return d; }) 
			.attr("value", function (d) { 
				return d; }); 

		//console.log(yValues)
		//console.log(xValues)

		var cValues = d3.set(heatData.map(function(d){
			return d["Count"]})).values();

		var color = d3.scaleQuantize()
			.domain(d3.extent(heatData, function(d){ 
			  	return d["Count"]}))
			.range(colors);

		var g = svg.append('g')
		  	.attr('transform', `translate(${margin.left}, ${margin.top})`);

		var yScale = d3.scaleBand()
		  	.domain(yValues)
		  	.range([0, innerHeight]);

		var yAxis = d3.axisLeft(yScale);

		var yAxisG = g.append('g')
			.call(yAxis)
		  	.style("text-anchor", "end");

		yAxisG.selectAll("text")	
		    .style("text-anchor", "end")
			.attr("x", "-10")
			.attr("y", "0");

		yAxisG.append('text')
		  	.attr('class','title')
		  	.attr('x', innerWidth /2)
		  	.attr('y', -15)
		  	.attr('text-anchor', 'middle')
		  	.text(title)
			//.style('font-size', '3.2em')
			//.style('fill', 'black');

		var xScale = d3.scaleBand()
		    .domain(xValues)
		    .range([0, innerWidth]);

		var xAxis = d3.axisBottom(xScale);

		var xAxisG = g.append('g')
			.call(xAxis)
			.style('line', 'white');

		xAxisG.selectAll("text")	
		    .style("text-anchor", "end")
			//.attr("x", "4")
			//.attr("y", 200)
			  .attr("dx", -250)
		    .attr("dy", "3.5em")
		    .attr("transform", "rotate(-65)")
			.select(".domain").remove();
		
		d3.select("#selectButton")
			.on("change", function(d){
				//console.log(this.value)
	    		//selection = this.value
	    		updateMap(this.value);
		});

	    var selectCategory = heatData.filter(function(d){
	      	return d["Category"] == ["10 to 99"]});
	  	
	    //console.log(selectLocation)
	    
		var tooltip = d3.selectAll("#tooltip")
			.append("div")
			.style("opacity", 0)
			.attr("class", "tooltip")
			.style("background-color", "white")
			.style("border", "solid")
			.style("border-width", "2px")
			.style("border-radius", "5px")
			.style("padding", "5px");

		var mouseover = function(d) {
			tooltip
				.style("opacity", 1);
				d3.select(this)
		  	.style("stroke", "black")
		  	.style("opacity", 1);
		};

		var mousemove = function(d) {
			tooltip
		  	.html("The exact value of<br>this cell is: " + d["Count"])
		  	.style("left", (d3.mouse(this)[0]+70) + "px")
		  	.style("top", (d3.mouse(this)[1]) + "px");
		};

		var mouseleave = function(d) {
			tooltip
		  	.style("opacity", 0);
			d3.select(this)
		  	.style("stroke", "none")
		  	.style("opacity", 0.8);
		};

	    svg.selectAll('category')
	      	.data(selectCategory)
	     	.enter()
	      	.append("rect")
	    	.attr("x", function(d) { 
	      		return xScale(d["States"]) + margin.left})
	    	.attr("y", function(d) { 
	      		return yScale(d["Year"]) + margin.top})
	    	.attr("rx", 4)
	   		.attr("ry", 4)
	    	.attr("width", xScale.bandwidth() )
	    	.attr("height", yScale.bandwidth() )
	    	.style('fill', function(d){
	      		return color(d["Count"])})
	    	.on("mouseover", mouseover)
	    	.on("mousemove", mousemove)
	    	.on("mouseleave", mouseleave);  

		var legendSize = 20;
		var legendData = d3.extent(heatData, function(d){
			return d["Count"]});
	  
		svg.selectAll("legend")
			.data(colors)
			.enter()
			.append("rect")
			.attr("x",width - 90)
			.attr("y",function(d,i){ 
				return 75 + i*(legendSize + 5)})
			.attr("width", 18)
			.attr("height", 6)
			.style("fill", function(d){return d});

		svg.selectAll("labels")
			.data(selectCategory)
			.enter()
			.append("text")
			.attr("x", width - 90 + legendSize * 1.4)
			.attr("y", function(d,i){ 
				return 75 + i*(legendSize+5) + (legendSize/2.75)})
			.text(function(d){return d["Count"]})
			.attr("text-anchor", "right")
			.style("alignment-baseline", "right")
			.style("font-size", ".75em")
			.style("font-weight", "bold");
	  
		function updateMap(selection){
			var updateCategory = heatData.filter(function(d){
	      	return d["Category"] == selection});

			console.log(updateCategory);
			svg.selectAll("category")
		      	.data(updateCategory)
		     	.enter()
		      	.append("rect")
		    	.attr("x", function(d) { 
		      		return xScale(d["States"]) + margin.left})
		    	.attr("y", function(d) { 
		      		return yScale(d["Year"]) + margin.top})
		    	.attr("rx", 4)
		   		.attr("ry", 4)
		    	.attr("width", xScale.bandwidth() )
		    	.attr("height", yScale.bandwidth() )
		    	.style("fill", function(d){
		      		return color(d["Count"])})
	    		.on("mouseover", mouseover)
	    		.on("mousemove", mousemove)
	    		.on("mouseleave", mouseleave);
	    
	    svg.selectAll("labels")
	      .data(updateCategory)
	      .enter()
	      .append("text")
	      .attr("x", width - 90 + legendSize * 1.4)
	      .attr("y", function(d,i){ 
	        return 75 + i*(legendSize+5) + (legendSize/2.75)})
	      .text(function(d){return d["Count"]})
	      .attr("text-anchor", "right")
	      .style("alignment-baseline", "right")
	      .style("font-size", ".75em")
	      .style("font-weight", "bold");
		}



	});